dSFMT: Globals

dSFMT 2.2

- Main Page
- Data Structures
- Files

- File List
- Globals

- All
- Functions
- Variables
- Typedefs
- Defines

- c
- d
- f
- g
- i
- p
- u
- w

Here is a list of all functions, variables, defines, enums, and typedefs with links to the files they belong to:

### - c -

- convert_c0o1() : dSFMT.c
- convert_o0c1() : dSFMT.c
- convert_o0o1() : dSFMT.c

### - d -

- do_recursion() : dSFMT-common.h
- dsfmt_chk_init_by_array() : dSFMT.h , dSFMT.c
- dsfmt_chk_init_gen_rand() : dSFMT.h , dSFMT.c
- dsfmt_fill_array_close1_open2() : dSFMT.h , dSFMT.c
- dsfmt_fill_array_close_open() : dSFMT.h , dSFMT.c
- dsfmt_fill_array_open_close() : dSFMT.h , dSFMT.c
- dsfmt_fill_array_open_open() : dSFMT.h , dSFMT.c
- dsfmt_gen_rand_all() : dSFMT.h , dSFMT.c
- dsfmt_genrand_close1_open2() : dSFMT.h
- dsfmt_genrand_close_open() : dSFMT.h
- dsfmt_genrand_open_close() : dSFMT.h
- dsfmt_genrand_open_open() : dSFMT.h
- dsfmt_genrand_uint32() : dSFMT.h
- dsfmt_get_idstring() : dSFMT.h , dSFMT.c
- dsfmt_get_min_array_size() : dSFMT.h , dSFMT.c
- dsfmt_global_data : dSFMT.h , dSFMT.c
- dsfmt_global_mexp : dSFMT.h
- dsfmt_gv_fill_array_close1_open2() : dSFMT.h
- dsfmt_gv_fill_array_close_open() : dSFMT.h
- dsfmt_gv_fill_array_open_close() : dSFMT.h
- dsfmt_gv_fill_array_open_open() : dSFMT.h
- dsfmt_gv_genrand_close1_open2() : dSFMT.h
- dsfmt_gv_genrand_close_open() : dSFMT.h
- dsfmt_gv_genrand_open_close() : dSFMT.h
- dsfmt_gv_genrand_open_open() : dSFMT.h
- dsfmt_gv_genrand_uint32() : dSFMT.h
- dsfmt_gv_init_by_array() : dSFMT.h
- dsfmt_gv_init_gen_rand() : dSFMT.h
- dsfmt_init_by_array() : dSFMT.h
- dsfmt_init_gen_rand() : dSFMT.h
- dsfmt_mexp : dSFMT.c
- DSFMT_MEXP : dSFMT.h
- DSFMT_N : dSFMT.h
- DSFMT_N32 : dSFMT.h
- DSFMT_N64 : dSFMT.h
- DSFMT_PRE_INLINE : dSFMT.h
- DSFMT_PST_INLINE : dSFMT.h
- dsfmt_t : dSFMT.h

### - f -

- fill_array_close1_open2() : dSFMT.h
- fill_array_close_open() : dSFMT.h
- fill_array_open_close() : dSFMT.h
- fill_array_open_open() : dSFMT.h

### - g -

- gen_rand_array_c0o1() : dSFMT.c
- gen_rand_array_c1o2() : dSFMT.c
- gen_rand_array_o0c1() : dSFMT.c
- gen_rand_array_o0o1() : dSFMT.c
- genrand_close1_open2() : dSFMT.h
- genrand_close_open() : dSFMT.h
- genrand_open_close() : dSFMT.h
- genrand_open_open() : dSFMT.h
- get_idstring() : dSFMT.h
- get_min_array_size() : dSFMT.h

### - i -

- idxof() : dSFMT.c
- ini_func1() : dSFMT.c
- ini_func2() : dSFMT.c
- init_by_array() : dSFMT.h
- init_gen_rand() : dSFMT.h
- initial_mask() : dSFMT.c
- inline : dSFMT.h

### - p -

- period_certification() : dSFMT.c
- PRIu64 : dSFMT.h
- PRIx64 : dSFMT.h

### - u -

- UINT64_C : dSFMT.h

### - w -

- w128_t : dSFMT.h